# Tests

Test specifications for all plugin, evaluator, model, config, and logger code.

- [[plugin-unit-tests]] — plugin helper and hook unit tests
- [[model-unit-tests]] — data model unit tests
- [[bradleyterry-evaluator-tests]] — BradleyTerry evaluator unit and integration tests
- [[pairwise-evaluator-tests]] — pairwise evaluator unit tests
- [[config-tests]] — Config pydantic-settings model tests
- [[logger-tests]] — logger tests
- [[plugin-integration-tests]] — full plugin end-to-end integration tests